@@ -3,7 +3,7 @@ BEGIN {
   $Dist::Zilla::PluginBundle::YANICK::AUTHORITY = 'cpan:YANICK';
 }
 {
-  $Dist::Zilla::PluginBundle::YANICK::VERSION = '0.17.0';
+  $Dist::Zilla::PluginBundle::YANICK::VERSION = '0.18.0';
 }
 
 # ABSTRACT: Be like Yanick when you build your dists
@@ -36,12 +36,12 @@ use Dist::Zilla::Plugin::Test::Compile;
 use Dist::Zilla::Plugin::Covenant;
 use Dist::Zilla::Plugin::SchwartzRatio;
 use Dist::Zilla::Plugin::PreviousVersion::Changelog;
-use Dist::Zilla::Plugin::ChangeStats::Git 0.2.0;
+use Dist::Zilla::Plugin::ChangeStats::Git;
 use Dist::Zilla::Plugin::Test::UnusedVars;
 use Dist::Zilla::Plugin::RunExtraTests;
 use Dist::Zilla::Plugin::HelpWanted;
 use Dist::Zilla::Plugin::CoderwallEndorse;
-use Dist::Zilla::Plugin::NextVersion::Semantic 0.1.2;
+use Dist::Zilla::Plugin::NextVersion::Semantic;
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
@@ -167,7 +167,7 @@ Dist::Zilla::PluginBundle::YANICK - Be like Yanick when you build your dists
 
 =head1 VERSION
 
-version 0.17.0
+version 0.18.0
 
 =head1 DESCRIPTION
 
